@@ -1,4 +1,5 @@
 ### =========================================================================
+
 ### VRanges: Variants in a GRanges
 ### -------------------------------------------------------------------------
 ###
@@ -163,7 +164,7 @@ parseFilterStrings <- function(x) {
   filterNames <- setdiff(unique(filters[!is.na(filters)]), "PASS")
   filterMat <- matrix(TRUE, length(x), length(filterNames),
                       dimnames = list(NULL, filterNames))
-  filterMat[cbind(togroup(filterSplit), match(filters, filterNames))] <- FALSE
+  filterMat[cbind(togroup(PartitioningByWidth(filterSplit)), match(filters, filterNames))] <- FALSE
   filterMat[is.na(x),] <- NA
   filterMat
 }
@@ -368,7 +369,7 @@ vranges2Vcf <- function(x, info = character(), filter = character(),
     stop("'filter' must be a character vector naming metadata(x) elements",
          " to include as metadata in the VCF header.")
   metaStrings <- as.character(sapply(metadata(x)[meta], as.character))
-  if (any(elementLengths(metaStrings) != 1L))
+  if (any(elementNROWS(metaStrings) != 1L))
     stop("The elements named in 'meta' must be of length 1")
 
   if (any(is.na(sampleNames(x)))) {
@@ -447,7 +448,7 @@ vranges2Vcf <- function(x, info = character(), filter = character(),
         v <- v[sample.ord]
       }
       ind <- unlist(samplesToUniq, use.names=FALSE) +
-        (togroup(samplesToUniq)-1L)*length(xUniq)
+        (togroup(PartitioningByWidth(samplesToUniq))-1L)*length(xUniq)
       a <- matrix(NA_integer_, nrow=length(xUniq)*length(sampleLevels),
                   ncol=width)
       a[ind,] <- v
@@ -474,7 +475,7 @@ vranges2Vcf <- function(x, info = character(), filter = character(),
     geno <- c(geno, SimpleList(lapply(mcols(x)[genoMCols], genoArray)))
 
   info <- mcols(xUniq)[info]
-  
+ 
   VCF(rowRanges = rowRanges, colData = colData, metadata = metadata,
       fixed = fixed, geno = geno, info = info, collapsed = FALSE)
 }
@@ -486,8 +487,7 @@ setMethod("asVCF", "VRanges", vranges2Vcf)
 ###
 
 VRangesScanVcfParam <- function(fixed="ALT", info=NA, geno="AD", ...) {
-  .Deprecated("ScanVcfParam")
-  ScanVcfParam(fixed=fixed, info=info, geno=geno, ...)
+  .Defunct("ScanVcfParam")
 }
 
 readVcfAsVRanges <- function(x, genome, param=ScanVcfParam(),
@@ -550,11 +550,11 @@ setMethod("duplicated", "VRanges",
             if (!identical(incomparables, FALSE))
               stop("\"duplicated\" method for VRanges objects ",
                    "only accepts 'incomparables=FALSE'")
-            S4Vectors:::duplicatedIntegerQuads(as.factor(seqnames(x)),
-                                               as.factor(alt(x)),
-                                               start(x), width(x),
-                                               fromLast = fromLast,
-                                               method = method)
+            duplicatedIntegerQuads(as.factor(seqnames(x)),
+                                   as.factor(alt(x)),
+                                   start(x), width(x),
+                                   fromLast = fromLast,
+                                   method = method)
           })
 
 setMethod("match", c("VRanges", "VRanges"),
@@ -571,15 +571,14 @@ setMethod("match", c("VRanges", "VRanges"),
             merge(seqinfo(x), seqinfo(table))
             altLevels <- as.character(union(alt(x), alt(table)))
             x_seqnames <- GenomicRanges:::relevelSeqnamesForMatch(x, table)
-            S4Vectors:::matchIntegerQuads(x_seqnames,
-                                          factor(as.character(alt(x)),
+            matchIntegerQuads(x_seqnames, factor(as.character(alt(x)),
                                                  altLevels),
-                                          start(x), width(x),
-                                          as.factor(seqnames(table)),
-                                          factor(as.character(alt(table)),
-                                                 altLevels),
-                                          start(table), width(table),
-                                          nomatch = nomatch, method = method)
+                              start(x), width(x),
+                              as.factor(seqnames(table)),
+                              factor(as.character(alt(table)),
+                                     altLevels),
+                              start(table), width(table),
+                              nomatch = nomatch, method = method)
           })
 
 setMethod("%in%", c("VRanges", "TabixFile"),
@@ -619,7 +618,7 @@ setMethod("merge", c("VRanges", "VRanges"), function(x, y, ...) {
 setMethod("liftOver", c("VRanges", "Chain"), function(x, chain, ...) {
   grl <- liftOver(GRanges(seqnames(x), ranges(x)), chain, ...)
   gr <- unlist(grl, use.names=FALSE)
-  ans <- x[togroup(grl)]
+  ans <- x[togroup(PartitioningByWidth(grl))]
   ans <- update(ans, seqinfo = seqinfo(gr), seqnames = seqnames(gr),
                 ranges = ranges(gr))
   relist(ans, grl)
